@@ -130,8 +130,7 @@ class Sheets:
             self.__adicionar(se)
 
     def restaurar(self, se):
-        add, worksheet = addicionar(se)
-        serializers.deserialize("json", self.lertabmod(worksheet), ignorenonexistent=True)
+        serializers.deserialize("json", self.lertabmod(se), ignorenonexistent=True)
 
 google_sheets = Sheets()
 
